@@ -51,7 +51,8 @@ class Bubble : public Plasma::Applet {
 
     public slots:
         void dataUpdated(QString name, Plasma::DataEngine::Data data);
-        
+        void configChanged();
+
     protected:
         QPainterPath shape() const;
         void constraintsEvent(Plasma::Constraints constraints);
@@ -62,7 +63,7 @@ class Bubble : public Plasma::Applet {
         void hoverLeaveEvent(QGraphicsSceneHoverEvent *event);
         
     private slots:
-        void configAccepted();
+        void writeConfig();
         void moveBubbles();
         void showLabel(bool);
         void interpolateValue();
