@@ -67,6 +67,8 @@ class MicroBlog : public Plasma::PopupApplet
     public slots:
         void dataUpdated(const QString &name, const Plasma::DataEngine::Data &data);
         void createConfigurationInterface( KConfigDialog *parent );
+        void configChanged();
+
         /**
          * read from the opened KWallet
          * @param success whether we got to open it
@@ -91,19 +93,20 @@ class MicroBlog : public Plasma::PopupApplet
         void showTweets();
         void modeChanged(int index);
         void openProfile(const QString &user = QString());
-        void reply(const QString &to);
+        void reply(const QString &replyToId, const QString &to);
         void forward(const QString &rt);
 
+        /**
+         * attempt to get the wallet from KWallet
+         * */
+        void getWallet();
+
     protected:
         bool eventFilter(QObject *obj, QEvent *event);
         void popupEvent(bool show);
         void focusInEvent(QFocusEvent *event);
 
     private:
-        /**
-         * attempt to get the wallet from KWallet
-         * */
-        void getWallet();
         /**
          * convenience function for setting the folder
          */
@@ -157,6 +160,7 @@ class MicroBlog : public Plasma::PopupApplet
         Plasma::Service *m_profileService;
         QSet<Plasma::ServiceJob *> m_updateJobs;
         QString m_curTimeline;
+        QString m_replyToId;
         Plasma::Frame *m_headerFrame;
 
         QMap<QString, QPixmap> m_pictureMap;
@@ -173,6 +177,7 @@ class MicroBlog : public Plasma::PopupApplet
         Ui::TwitterConfig configUi;
 
         QTimer *m_showTweetsTimer;
+        QTimer *m_getWalletDelayTimer;
 };
 
 K_EXPORT_PLASMA_APPLET(microblog, MicroBlog)
