@@ -22,16 +22,21 @@
 #include "Helpers.h"
 #include <QPainter>
 
+#include <Plasma/Theme>
+
 ShiftKey::ShiftKey(QPoint relativePosition, QSize relativeSize) :
-        StickyKey(relativePosition, relativeSize, Helpers::keysymToKeycode(XK_Shift_L), QString()){
+        StickyKey(relativePosition, relativeSize, Helpers::keysymToKeycode(XK_Shift_L), QString())
+{
 
 }
 
-void ShiftKey::paint(QPainter *painter){
+void ShiftKey::paint(QPainter *painter)
+{
     FuncKey::paint(painter);
 
     painter->save();
     painter->setRenderHint(QPainter::Antialiasing);
+    painter->setPen(Plasma::Theme::defaultTheme()->color(Plasma::Theme::ButtonTextColor));
     setUpPainter(painter);
     int unit = qMin(size().width(), size().height()) / 8;
 
