@@ -22,18 +22,20 @@
 #include "Helpers.h"
 #include <QPainter>
 
+#include <Plasma/Theme>
 
 TabKey::TabKey(QPoint relativePosition, QSize relativeSize) :
-        FuncKey(relativePosition, relativeSize, Helpers::keysymToKeycode(XK_Tab), QString()){
-
+        FuncKey(relativePosition, relativeSize, Helpers::keysymToKeycode(XK_Tab), QString())
+{
 }
 
-void TabKey::paint(QPainter *painter){
-
+void TabKey::paint(QPainter *painter)
+{
     FuncKey::paint(painter);
 
     painter->save();
     painter->setRenderHint(QPainter::Antialiasing);
+    painter->setPen(Plasma::Theme::defaultTheme()->color(Plasma::Theme::ButtonTextColor));
     setUpPainter(painter);
     int unit = qMin(size().width(), size().height()) / 8;
 
